from setuptools import setup

setup(name='neuropot',
      version='0.1',
      description='Python package to preprocess brain MRI images and carry out population transfer and transfer learning',
      url='https://github.com/MEDCOMP/neuropot',
      author='Abhinit Ambastha',
      author_email='abhinit@comp.nus.edu.sg',
      license='MIT',
      packages=['neuropot'],
      zip_safe=False)